@@ -42,7 +42,7 @@ def main():
 
                             of = open(sb + os.sep + fn, "r", encoding="utf-8")
                             correct = of.read().strip()
-                            if out != correct:
+                            if str(out) != str(correct):
                                 print("Wrong Answer on", i)
                                 print("Output:", out)
                                 print("\nExpected:", correct)
